import * as pulumi from "@pulumi/pulumi";
/**
 * Provides a Wavefront Cloud Integration for CloudWatch. This allows CloudWatch cloud integrations to be created,
 * updated, and deleted.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as wavefront from "@pulumi/wavefront";
 *
 * const extId = new wavefront.CloudIntegrationAwsExternalId("ext_id", {});
 * const cloudwatch = new wavefront.CloudIntegrationCloudWatch("cloudwatch", {
 *     name: "Test Integration",
 *     forceSave: true,
 *     roleArn: "arn:aws::1234567:role/example-arn",
 *     externalId: extId.id,
 * });
 * ```
 *
 * ## Import
 *
 * CloudWatch Cloud Integrations can be imported by using the `id`, e.g.:
 *
 * ```sh
 * $ pulumi import wavefront:index/cloudIntegrationCloudWatch:CloudIntegrationCloudWatch cloudwatch a411c16b-3cf7-4f03-bf11-8ca05aab898d
 * ```
 */
export declare class CloudIntegrationCloudWatch extends pulumi.CustomResource {
    /**
     * Get an existing CloudIntegrationCloudWatch resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: CloudIntegrationCloudWatchState, opts?: pulumi.CustomResourceOptions): CloudIntegrationCloudWatch;
    /**
     * Returns true if the given object is an instance of CloudIntegrationCloudWatch.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is CloudIntegrationCloudWatch;
    /**
     * A list of point tag key-values to add to every point ingested using this integration.
     */
    readonly additionalTags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * The Role ARN that the customer has created in AWS IAM to allow access to Wavefront.
     */
    readonly externalId: pulumi.Output<string>;
    /**
     * Forces this resource to save, even if errors are present.
     */
    readonly forceSave: pulumi.Output<boolean | undefined>;
    /**
     * A string->string map allow list of instance tag-value pairs (in AWS).
     * If the instance's AWS tags match this allow list, CloudWatch data about this instance is ingested.
     * Multiple entries are OR'ed.
     */
    readonly instanceSelectionTags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * A regular expression that a CloudWatch metric name must match (case-insensitively) in order to be ingested.
     */
    readonly metricFilterRegex: pulumi.Output<string | undefined>;
    /**
     * The human-readable name of this integration.
     */
    readonly name: pulumi.Output<string>;
    /**
     * A list of namespaces that limit what we query from CloudWatch.
     */
    readonly namespaces: pulumi.Output<string[] | undefined>;
    /**
     * A regular expression that AWS tag key name must match (case-insensitively)
     * in order to be ingested.
     */
    readonly pointTagFilterRegex: pulumi.Output<string | undefined>;
    /**
     * The external ID corresponding to the Role ARN.
     */
    readonly roleArn: pulumi.Output<string>;
    /**
     * A value denoting which cloud service this service integrates with.
     */
    readonly service: pulumi.Output<string>;
    /**
     * How often, in minutes, to refresh the service.
     */
    readonly serviceRefreshRateInMinutes: pulumi.Output<number | undefined>;
    /**
     * A string->string map of allow list of volume tag-value pairs (in AWS).
     * If the volume's AWS tags match this allow list, CloudWatch data about this volume is ingested.
     * Multiple entries are OR'ed.
     */
    readonly volumeSelectionTags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Create a CloudIntegrationCloudWatch resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: CloudIntegrationCloudWatchArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering CloudIntegrationCloudWatch resources.
 */
export interface CloudIntegrationCloudWatchState {
    /**
     * A list of point tag key-values to add to every point ingested using this integration.
     */
    additionalTags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * The Role ARN that the customer has created in AWS IAM to allow access to Wavefront.
     */
    externalId?: pulumi.Input<string>;
    /**
     * Forces this resource to save, even if errors are present.
     */
    forceSave?: pulumi.Input<boolean>;
    /**
     * A string->string map allow list of instance tag-value pairs (in AWS).
     * If the instance's AWS tags match this allow list, CloudWatch data about this instance is ingested.
     * Multiple entries are OR'ed.
     */
    instanceSelectionTags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * A regular expression that a CloudWatch metric name must match (case-insensitively) in order to be ingested.
     */
    metricFilterRegex?: pulumi.Input<string>;
    /**
     * The human-readable name of this integration.
     */
    name?: pulumi.Input<string>;
    /**
     * A list of namespaces that limit what we query from CloudWatch.
     */
    namespaces?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * A regular expression that AWS tag key name must match (case-insensitively)
     * in order to be ingested.
     */
    pointTagFilterRegex?: pulumi.Input<string>;
    /**
     * The external ID corresponding to the Role ARN.
     */
    roleArn?: pulumi.Input<string>;
    /**
     * A value denoting which cloud service this service integrates with.
     */
    service?: pulumi.Input<string>;
    /**
     * How often, in minutes, to refresh the service.
     */
    serviceRefreshRateInMinutes?: pulumi.Input<number>;
    /**
     * A string->string map of allow list of volume tag-value pairs (in AWS).
     * If the volume's AWS tags match this allow list, CloudWatch data about this volume is ingested.
     * Multiple entries are OR'ed.
     */
    volumeSelectionTags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
/**
 * The set of arguments for constructing a CloudIntegrationCloudWatch resource.
 */
export interface CloudIntegrationCloudWatchArgs {
    /**
     * A list of point tag key-values to add to every point ingested using this integration.
     */
    additionalTags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * The Role ARN that the customer has created in AWS IAM to allow access to Wavefront.
     */
    externalId: pulumi.Input<string>;
    /**
     * Forces this resource to save, even if errors are present.
     */
    forceSave?: pulumi.Input<boolean>;
    /**
     * A string->string map allow list of instance tag-value pairs (in AWS).
     * If the instance's AWS tags match this allow list, CloudWatch data about this instance is ingested.
     * Multiple entries are OR'ed.
     */
    instanceSelectionTags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * A regular expression that a CloudWatch metric name must match (case-insensitively) in order to be ingested.
     */
    metricFilterRegex?: pulumi.Input<string>;
    /**
     * The human-readable name of this integration.
     */
    name?: pulumi.Input<string>;
    /**
     * A list of namespaces that limit what we query from CloudWatch.
     */
    namespaces?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * A regular expression that AWS tag key name must match (case-insensitively)
     * in order to be ingested.
     */
    pointTagFilterRegex?: pulumi.Input<string>;
    /**
     * The external ID corresponding to the Role ARN.
     */
    roleArn: pulumi.Input<string>;
    /**
     * A value denoting which cloud service this service integrates with.
     */
    service: pulumi.Input<string>;
    /**
     * How often, in minutes, to refresh the service.
     */
    serviceRefreshRateInMinutes?: pulumi.Input<number>;
    /**
     * A string->string map of allow list of volume tag-value pairs (in AWS).
     * If the volume's AWS tags match this allow list, CloudWatch data about this volume is ingested.
     * Multiple entries are OR'ed.
     */
    volumeSelectionTags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
